<?php

namespace Drupal\restrict_route_by_ip\Controller;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Routing\RedirectDestination;
use Drupal\Core\Routing\RouteBuilderInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a listing of RestrictRoute.
 */
class StatusController extends ControllerBase {

  /**
   * The Drupal RouteBuilder service
   *
   * @var \Drupal\Core\Routing\RouteBuilderInterface
   */
  protected $routeBuilder;

  /**
   * StatusController constructor.
   *
   * @param \Drupal\Core\Routing\RouteBuilderInterface $route_builder
   *   The form builder.
   */
  public function __construct(RouteBuilderInterface $route_builder) {
    $this->routeBuilder = $route_builder;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The Drupal service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('router.builder')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function enable(EntityInterface $restrict_route) {
    $restrict_route->setStatus(TRUE);
    $restrict_route->save();
    $this->messenger()->addMessage($this->t('Route @label enabled.', [
      '@label' => $restrict_route->label()
    ]));
    $this->routeBuilder->rebuild();
    return  $this->redirect('entity.restrict_route.collection');
  }

  /**
   * {@inheritdoc}
   */
  public function disable(EntityInterface $restrict_route) {
    $restrict_route->setStatus(FALSE);
    $restrict_route->save();
    $this->messenger()->addMessage($this->t('Route @label disabled.', [
      '@label' => $restrict_route->label()
    ]));
    $this->routeBuilder->rebuild();
    return  $this->redirect('entity.restrict_route.collection');
  }

}
